@@ -37,11 +37,17 @@ def init_report_sonar(
     pipeline_name = devops_platform_gateway.get_variable("pipeline_name")
     branch = devops_platform_gateway.get_variable("branch_tag")
 
-    is_valid_pipeline = not re.match(
-        report_config_tool["IGNORE_SEARCH_PATTERN"], 
-        pipeline_name, 
-        re.IGNORECASE
-    ) and pipeline_name not in excluded_pipelines
+    is_valid_pipeline = pipeline_name not in excluded_pipelines and not any(
+        [
+            re.match(
+                pattern,
+                pipeline_name,
+                re.IGNORECASE
+            ) for pattern in
+            [report_config_tool["IGNORE_SEARCH_PATTERN"]] +
+            list(excluded_pipelines.get("BY_PATTERN_SEARCH", {}).keys())
+        ]
+    )
     
     is_valid_branch = any(
         target_branch in str(branch).split("/")
